<template>
  <div>
    <ProTableV2
      :tableData="list"
      :columns="columns"
      :autoHeight="false"
      :operationBtns="columnsProps.operationBtns"
      :operationColumnWidth="240"
      :showTableColumnSetting="false"
    >
      <template #fileBusinessType="{ row }">
        {{ FourStreamsMaterialFileBusinessTypeEnumText[row.fileBusinessType] }}
      </template>
      <template #operationBtn-uploadBtn="{ data, row }">
        <BlFileUpload
          v-model:file-url="row.fileList"
          multiple
          :limit="1"
          ref="uploadRef"
          :showTip="false"
          :show-file-list="false"
          class="pro-table-operation-btn upload-style-btn"
        >
          <el-button text type="primary" class="pro-table-operation-btn">上传</el-button>
        </BlFileUpload>
      </template>
    </ProTableV2>
  </div>
</template>

<script setup lang="ts">
import {
  FourStreamsMaterialFileTableProps,
  FourStreamsMaterialFileTableItem,
  FourStreamsMaterialFileBusinessTypeEnumText,
} from './types';
import {
  ProTableV2,
  defineColumns,
  defineOperationBtns,
  BlFileUpload,
  bolePreview,
} from '@bole-core/components';
import { downloadFileByUrl } from '@/utils';
import { Message, isFileCanPreview } from '@bole-core/core';
import { useDefineColumns } from '@/hooks';

defineOptions({
  name: 'FourStreamsMaterialFileTable',
});

const props = withDefaults(defineProps<FourStreamsMaterialFileTableProps>(), {
  showUploadBtn: true,
  showCheckBtn: true,
  showDownloadBtn: true,
  showDeleteBtn: true,
  downloadBtnText: '下载',
});

const list = defineModel<FourStreamsMaterialFileTableItem[]>('list');

const columns = defineColumns([
  {
    id: '1',
    enCode: 'fileBusinessType',
    name: '材料名称',
  },
]);

const columnsProps = useDefineColumns({
  operationBtns: [
    {
      data: {
        enCode: 'uploadBtn',
        name: '上传',
      },
      extraProps: {
        hide: (row: FourStreamsMaterialFileTableItem) => {
          if (!props.showUploadBtn) return true;
          let fileList = row?.fileList?.filter?.((item) => item.status === 'success');
          return fileList?.length > 0;
        },
      },
    },
    {
      data: {
        enCode: 'detailBtn',
        name: '查看',
      },
      emits: {
        onClick: (row) => handlePreview(row),
      },
      extraProps: {
        hide: (row: FourStreamsMaterialFileTableItem) => {
          if (!props.showCheckBtn) return true;
          let fileList = row?.fileList?.filter?.((item) => item.status === 'success');
          if (!fileList?.length) {
            return true;
          } else {
            if (fileList.length > 1) {
              return false;
            } else {
              return !isFileCanPreview(fileList[0].path);
            }
          }
        },
      },
    },
    {
      data: {
        enCode: 'downloadBtn',
        name: props.downloadBtnText,
      },
      emits: {
        onClick: (row) => handleBatchDownload(row),
      },
      extraProps: {
        hide: (row: FourStreamsMaterialFileTableItem) => {
          return (
            !props.showDownloadBtn ||
            !row?.fileList?.filter?.((item) => item.status === 'success')?.length
          );
        },
      },
    },
    {
      data: {
        enCode: 'delBtn',
        name: '删除',
      },
      props: {
        type: 'danger',
      },
      emits: {
        onClick: (row) => handleDelete(row),
      },
      extraProps: {
        hide: (row: FourStreamsMaterialFileTableItem) => {
          if (!props.showDeleteBtn) return true;
          let fileList = row?.fileList?.filter?.((item) => item.status === 'success');
          return !fileList?.length;
        },
      },
    },
  ],
});

async function handleDelete(row: FourStreamsMaterialFileTableItem) {
  try {
    await Message.deleteMessage();
    row.fileList = [];
  } catch (error) {}
}

async function handlePreview(row: FourStreamsMaterialFileTableItem) {
  if (row.fileList.length > 1) {
    // currentEnterpriseMaterialFileTableItem.value = row;
    // await nextTick();
    // dialogState.dialogVisible = true;
  } else {
    bolePreview({
      fileUrl: row.fileList[0].url,
    });
  }
}

function handleBatchDownload(row: FourStreamsMaterialFileTableItem) {
  const successFileList = row.fileList.filter((item) => item.status === 'success');
  if (successFileList.length === 0) {
    Message.errorMessage('没有可下载的文件');
    return;
  }
  if (successFileList.length === 1) {
    downloadFileByUrl(successFileList[0].url);
  } else {
    // downloadWithZip(
    //   successFileList.map((item) => ({ data: item.url })),
    //   `${AllEnterpriseMaterialFileBusinessTypeEnumText[row.fileBusinessType]}材料文件`
    // );
  }
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
